@@ -1,22 +1,29 @@
 import numpy as np
 from typing import List
 import re
+import matplotlib.pyplot as plt
+from variables import *
+
 
 U_RE = re.compile(r"^(?P<name>.+?)(?:\((?P<unit>.+)\))?$", flags=re.MULTILINE)
 
 
 class VariableList2D:
     def __init__(self, name: str, xi=0, yi=0):
-        init = np.array([xi, yi])
-        self.name = name
-        self.vals: List[np.ndarray] = [init]
+        match = U_RE.match(name)
+        self.unit = (match.group("unit") or "").strip()
+        self.var_name = match.group("name").strip()
+        self.name = f'{self.var_name}{f" ({self.unit})" if self.unit else ""}'.strip()
+
+        initial = np.array([xi, yi])
+        self.vals: np.ndarray[np.ndarray] = np.array([initial])
 
     def append(self, x, y):
         arr = np.array([x, y])
-        self.vals.append(arr)
+        self.add(arr)
 
     def add(self, arr: np.ndarray):
-        self.vals.append(arr)
+        self.vals = np.vstack((self.vals, arr))
 
     def __iadd__(self, other):
         """Adds other to the last value, then appends"""
@@ -48,6 +55,37 @@ class VariableList2D:
     def x_values(self):
         return np.array([x[0] for x in self.vals])
 
+    @property
+    def x_name(self):
+        return f"X {self.name}"
+
     @property
     def y_values(self):
         return np.array([x[1] for x in self.vals])
+
+    @property
+    def y_name(self):
+        return f"Y {self.name}"
+
+
+def scatter_2d(x_list, y_list):
+    if isinstance(x_list, VariableList):
+        x_name = x_list.name
+        x_vals = x_list
+    else:
+        x_name = x_list.x_name
+        x_vals = x_list.x_values
+
+    if isinstance(y_list, VariableList):
+        y_name = y_list.name
+        y_vals = y_vals
+    else:
+        y_name = y_list.y_name
+        y_vals = y_list.y_values
+
+    plt.scatter(x_vals, y_vals)
+    plt.xlabel(x_name)
+    plt.ylabel(y_name)
+    plt.title(f"{x_name} vs {y_name}")
+
+    return plt
